@@ -2,12 +2,13 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import party
-from . import sale
+
+from . import party, sale
 
 
 def register():
     Pool.register(
         party.Party,
         sale.Sale,
+        sale.Line,
         module='sale_credit_limit', type_='model')
